@@ -127,25 +127,26 @@ def getNoiseProfileLine(tokens, i):
     return line
 
 def assignParents(tokens):
+    commonorder = [";", ". ", "\n",":\n", "\|", "-", ": "]
     ranks = {}
     ranks["root"] = "root"
     ranks["\n"] = [":\n", "root"]
     ranks[":\n"] = ["\n", "root"]
     ranks[": "] = ["\n", ". ", ";"]
     ranks[". "] = ["\n", ":\n"]
-    ranks[","] = [";", ". ", "\n", ":\n","|", "-", ": "]
+    ranks["\,"] = commonorder
     ranks[";"] = [". ", "\n",":\n"]
-    ranks["-"] = [";", ". ", "\n",":\n", ",", "|"]
-    ranks["|"] = [";", ". ", "\n",":\n", ",", "|"]
-    ranks["and"] = [";", ". ", "\n",":\n", "|", "-"]
-    ranks["or"] = [";", ". ", "\n",":\n", "|", "-"]
-    ranks["by"] = [";", ". ", "\n",":\n", ",", "|", "-"]
-    ranks["in"] = [";", ". ", "\n",":\n", ",", "|", "-"]
-    ranks["on"] = [";", ". ", "\n",":\n", ",", "|", "-"]
-    ranks["was"] = [";", ". ", "\n", ":\n",",", "|", "-"]
-    ranks["is"] = [";", ". ", "\n",":\n", ",", "|", "-"]
+    ranks["-"] = commonorder
+    ranks["\|"] = commonorder
+    ranks["(\s|^)and(\s|^)"] = commonorder
+    ranks["(\s|^)or(\s|^)"] = commonorder
+    ranks["(\s|^)by(\s|^)"] = commonorder
+    ranks["(\s|^)in(\s|^)"] = commonorder
+    ranks["(\s|^)on(\s|^)"] = commonorder
+    ranks["(\s|^)was(\s|^)"] = commonorder
+    ranks["(\s|^)is(\s|^)"] = commonorder
 
-    order = [":\n", "\n", ". ", ";", ": ", ",", "-", "and", "or", "|", "by", "in", "on", "was", "is"]
+    order = [":\n", "\n", ". ", ";", ": ", ",", "\-", "\|", "(\s|^)and(\s|^)", "(\s|^)or(\s|^)", "(\s|^)by(\s|^)", "(\s|^)in(\s|^)", "(\s|^)on(\s|^)", "(\s|^)was(\s|^)", "(\s|^)is(\s|^)"]
 
     lastKnown = {}
     lastKnownKeys = order + ["root", "newLineAny"]
@@ -160,10 +161,7 @@ def assignParents(tokens):
         snip = tokens[i]["token"]
         done = False
         for ord in order:
-            if ord not in snip:
-                continue
-
-            if ord in snip:
+            if re.search(ord, tokens[i]["token"].lower()):
                 prev = np.amax(np.array(list([lastKnown[r] for r in ranks[ord]])))
 
                 ## if its a plain new line, determining if it should return to root.
